@@ -1,5 +1,5 @@
 from .core import validate
-from .validators import required, format_email, length_max, length_min, length, type_, lt, gt, eq, ne, gte, lte, _value, regex_, true_if_empty, in_
+from .validators import required, format_email, length_max, length_min, length, type_, lt, gt, eq, ne, gte, lte, _value, regex_, true_if_empty, in_, skip_on_fail
 from .decorators import validate_fn
 from .utils import dummy_gettext, selector_as_string
 
@@ -23,4 +23,5 @@ __all__ = ['validate',
            'lte',
            'true_if_empty',
            'dummy_gettext',
-           'selector_as_string']
+           'selector_as_string',
+           'skip_on_fail']
